@@ -5,10 +5,12 @@ from unittest.mock import Mock
 
 import pytest
 
+from pygls import IS_PYODIDE
 from pygls.server import LanguageServer
 
 
 @pytest.mark.asyncio
+@pytest.mark.skipif(IS_PYODIDE, reason='threads are not available in pyodide.')
 async def test_tcp_connection_lost():
     loop = asyncio.new_event_loop()
 
@@ -18,17 +20,23 @@ async def test_tcp_connection_lost():
     server.lsp.connection_lost = Mock()
 
     # Run the server over TCP in a separate thread
-    server_thread = Thread(target=server.start_tcp, args=('127.0.0.1', 0, ))
+    server_thread = Thread(
+        target=server.start_tcp,
+        args=(
+            "127.0.0.1",
+            0,
+        ),
+    )
     server_thread.daemon = True
     server_thread.start()
 
     # Wait for server to be ready
     while server._server is None:
-        await asyncio.sleep(.5)
+        await asyncio.sleep(0.5)
 
     # Simulate client's connection
     port = server._server.sockets[0].getsockname()[1]
-    reader, writer = await asyncio.open_connection('127.0.0.1', port)
+    reader, writer = await asyncio.open_connection("127.0.0.1", port)
     await asyncio.sleep(1)
 
     assert server.lsp.connection_made.called
@@ -39,7 +47,9 @@ async def test_tcp_connection_lost():
 
     assert server.lsp.connection_lost.called
 
+
 @pytest.mark.asyncio
+@pytest.mark.skipif(IS_PYODIDE, reason='threads are not available in pyodide.')
 async def test_io_connection_lost():
     # Client to Server pipe.
     csr, csw = os.pipe()
@@ -50,14 +60,17 @@ async def test_io_connection_lost():
     server.lsp.connection_made = Mock()
     server_thread = Thread(
         target=server.start_io,
-        args=(os.fdopen(csr, 'rb'), os.fdopen(scw, 'wb'))
+        args=(
+            os.fdopen(csr, "rb"),
+            os.fdopen(scw, "wb")
+        )
     )
     server_thread.daemon = True
     server_thread.start()
 
     # Wait for server to be ready
     while not server.lsp.connection_made.called:
-        await asyncio.sleep(.5)
+        await asyncio.sleep(0.5)
 
     # Pipe is closed (client's process is terminated)
     os.close(csw)
